@@ -24,4 +24,8 @@ with tempfile.TemporaryDirectory() as dir:
     #     for t in indexer.iter(i):
     #         print(i, t.docid, t.value)
 
-    print([(d.docid, d.score) for d in index.search({1: .2, 5: .5}, 10)])
\ No newline at end of file
+    print([(d.docid, d.score) for d in index.search({1: .2, 5: .5}, 10)])
+
+    print("Load index from disk")
+    index = xpmir_rust.index.SparseBuilderIndex.load(dir)
+    print([(d.docid, d.score) for d in index.search({1: .2, 5: .5}, 10)])
